pub enum ContextCompactionMode {
KeepRecentRawSuffix,
CompactToSafeFrontier,
}Expand description
Auto-compaction strategy used by [ContextPlugin].
Variants
KeepRecentRawSuffix
Replace an older prefix with a summary while preserving a recent raw suffix.
CompactToSafeFrontier
Replace all messages through the latest safe frontier with a summary.