pub fn run_lifecycle_from_state(state: &Value) -> Option<RunLifecycleState>Expand description
Parse persisted run lifecycle from a rebuilt state snapshot.
pub fn run_lifecycle_from_state(state: &Value) -> Option<RunLifecycleState>Parse persisted run lifecycle from a rebuilt state snapshot.