pub struct MessageQuery {
pub after: Option<i64>,
pub before: Option<i64>,
pub limit: usize,
pub order: SortOrder,
pub visibility: Option<Visibility>,
pub run_id: Option<String>,
}Expand description
Cursor-based pagination parameters for messages.
Fields
after: Option<i64>Return messages with cursor strictly greater than this value.
before: Option<i64>Return messages with cursor strictly less than this value.
limit: usizeMaximum number of messages to return (clamped to 1..=200).
order: SortOrderSort order.
visibility: Option<Visibility>Filter by message visibility. None means return all messages.
run_id: Option<String>Filter by run ID. None means return all runs.