pub struct RunMeta {
pub agent_id: String,
pub origin: RunOrigin,
pub status: RunStatus,
pub parent_thread_id: Option<String>,
pub termination_code: Option<String>,
pub termination_detail: Option<String>,
}Expand description
Run-level metadata carried in a ThreadChangeSet.
When present, the thread store uses this to maintain a run index. Set on the first changeset of a run (to create the record) and the last (to finalize status / termination).
Fields
agent_id: Stringorigin: RunOriginstatus: RunStatusparent_thread_id: Option<String>termination_code: Option<String>termination_detail: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for RunMeta
impl<'de> Deserialize<'de> for RunMeta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more